Module beamlit.models.revision_metadata
=======================================

Classes
-------

`RevisionMetadata(created_at: beamlit.types.Unset | str = <beamlit.types.Unset object>, id: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   Revision metadata
    
    Attributes:
        created_at (Union[Unset, str]): Revision created at
        id (Union[Unset, str]): Revision ID
    
    Method generated by attrs for class RevisionMetadata.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `created_at: beamlit.types.Unset | str`
    :

    `id: beamlit.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :